@@ -19,9 +19,6 @@ package org.apache.maven.reporting;
  * under the License.
  */
 
-import org.apache.commons.validator.EmailValidator;
-import org.apache.commons.validator.UrlValidator;
-
 import org.apache.maven.doxia.sink.Sink;
 import org.apache.maven.doxia.util.HtmlTools;
 
@@ -41,7 +38,7 @@ import java.util.Properties;
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
  * @author <a href="evenisse@apache.org">Emmanuel Venisse</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: AbstractMavenReportRenderer.java 1379502 2012-08-31 16:43:35Z struberg $
+ * @version $Id: AbstractMavenReportRenderer.java 1781702 2017-02-04 20:15:14Z michaelo $
  * @since 2.0
  * @TODO Later it may be appropriate to create something like a VelocityMavenReportRenderer
  * that could take a velocity template and pipe that through Doxia rather than coding them
@@ -342,7 +339,6 @@ public abstract class AbstractMavenReportRenderer
 
     /**
      * Convenience method to wrap a table header row start in the current sink.
-     * <p>The texts in the <code>content</code> could be link patterned texts defined by <code>{text, url}</code></p>
      *
      * @param content an array of text to put in the cells in this row header, could be null.
      * @see #tableHeaderCell(String)
@@ -530,14 +526,7 @@ public abstract class AbstractMavenReportRenderer
                     }
                     else
                     {
-                        if ( getValidHref( href ) != null )
-                        {
-                            link( getValidHref( href ), name );
-                        }
-                        else
-                        {
-                            text( href );
-                        }
+                       link( href, name );
                     }
                 }
             }
@@ -601,71 +590,6 @@ public abstract class AbstractMavenReportRenderer
     // Private methods
     // ----------------------------------------------------------------------
 
-    /**
-     * Return a valid href.
-     * <p>A valid href could start by <code>mailto:</code>.</p>
-     * <p>For a relative path, the href should start by <code>./</code> to be valid.</p>
-     *
-     * @param href an href, could be null.
-     * @return a valid href or <code>null</code> if the href is null or not valid.
-     */
-    private static String getValidHref( String href )
-    {
-        if ( StringUtils.isEmpty( href ) )
-        {
-            return null;
-        }
-
-        href = href.trim();
-
-        String[] schemes = {"http", "https"};
-        UrlValidator urlValidator = new UrlValidator( schemes );
-        EmailValidator emailValidator = EmailValidator.getInstance();
-
-        if ( emailValidator.isValid( href )
-            || ( href.contains( "?" ) && emailValidator.isValid( href.substring( 0, href.indexOf( "?" ) ) ) ) )
-        {
-            return "mailto:" + href;
-        }
-        else if ( href.toLowerCase().startsWith( "mailto:" ) )
-        {
-            return href;
-        }
-        else if ( urlValidator.isValid( href ) )
-        {
-            return href;
-        }
-        else
-        {
-            String hrefTmp;
-            if ( !href.endsWith( "/" ) )
-            {
-                hrefTmp = href + "/index.html";
-            }
-            else
-            {
-                hrefTmp = href + "index.html";
-            }
-
-            if ( urlValidator.isValid( hrefTmp ) )
-            {
-                return href;
-            }
-
-            if ( href.startsWith( "./" ) )
-            {
-                if ( href.length() > 2 )
-                {
-                    return href.substring( 2, href.length() );
-                }
-
-                return ".";
-            }
-
-            return null;
-        }
-    }
-
     /**
      * The method parses a text and applies the given pattern <code>{text, url}</code> to create
      * a list of text/href.
@@ -735,7 +659,7 @@ public abstract class AbstractMavenReportRenderer
                         {
                             if ( braceStack == 0 )
                             {
-                                if ( i != 0 ) // handle { at first character
+                                if ( i != lastOffset ) // handle { at first character
                                 {
                                     segments.add( text.substring( lastOffset, i ) );
                                     segments.add( null );
